@@ -42,8 +42,10 @@
 #define RETRIEVE_DOMAIN_ERROR_MSG "Error (%d [%s]) retrieving domain [%s], "\
                                   "skipping!\n"
 
+#ifdef BUILD_FILES_PROVIDER
 /* SSSD domain name that is used for the auto-configured files domain */
 #define IMPLICIT_FILES_DOMAIN_NAME "implicit_files"
+#endif
 
 static int confdb_get_domain_enabled(struct confdb_ctx *cdb,
                                      const char *domain, bool *_enabled);
@@ -1039,6 +1041,7 @@ static errno_t confdb_init_domain(struct sss_domain_info *domain,
 
     domain->state = DOM_ACTIVE;
 
+#ifdef BUILD_FILES_PROVIDER
     domain->fallback_to_nss = false;
     if (is_files_provider(domain)) {
         ret = get_entry_as_bool(res->msgs[0], &domain->fallback_to_nss,
@@ -1049,6 +1052,7 @@ static errno_t confdb_init_domain(struct sss_domain_info *domain,
             goto done;
         }
     }
+#endif
 
     domain->not_found_counter = 0;
     ret = EOK;
@@ -1153,7 +1157,8 @@ static errno_t confdb_init_domain_fqn(struct confdb_ctx *cdb,
     /* Determine if user/group names will be Fully Qualified
      * in NSS interfaces */
     if (default_domain != NULL
-             && is_files_provider(domain) == false) {
+             && is_files_provider(domain) == false
+             ) {
         DEBUG(SSSDBG_CONF_SETTINGS,
               "Default domain suffix set. Changing default for "
               "use_fully_qualified_names to True.\n");
@@ -1170,7 +1175,8 @@ static errno_t confdb_init_domain_fqn(struct confdb_ctx *cdb,
 
     if (default_domain != NULL
             && domain->fqnames == false
-            && is_files_provider(domain) == false) {
+            && is_files_provider(domain) == false
+            ) {
         DEBUG(SSSDBG_FATAL_FAILURE,
               "Invalid configuration detected (default_domain_suffix is used "
               "while use_fully_qualified_names was set to false).\n");
@@ -1397,7 +1403,9 @@ static errno_t confdb_init_domain_user_info(struct sss_domain_info *domain,
                                       CONFDB_NSS_OVERRIDE_HOMEDIR, NULL);
     /* Here we skip the files provider as it should always return *only*
      * what's in the files and nothing else. */
-    if (tmp != NULL && !is_files_provider(domain)) {
+    if (tmp != NULL
+        && !is_files_provider(domain)
+        ) {
         domain->override_homedir = talloc_strdup(domain, tmp);
         if (!domain->override_homedir) {
             ret = ENOMEM;
@@ -1448,7 +1456,9 @@ static errno_t confdb_init_domain_user_info(struct sss_domain_info *domain,
     tmp = ldb_msg_find_attr_as_string(res->msgs[0], CONFDB_NSS_OVERRIDE_SHELL, NULL);
     /* Here we skip the files provider as it should always return *only*
      * what's in the files and nothing else. */
-    if (tmp != NULL && !is_files_provider(domain)) {
+    if (tmp != NULL
+        && !is_files_provider(domain)
+        ) {
         domain->override_shell = talloc_strdup(domain, tmp);
         if (!domain->override_shell) {
             ret = ENOMEM;
@@ -2027,6 +2037,7 @@ done:
     return ret;
 }
 
+#ifdef BUILD_FILES_PROVIDER
 static bool need_implicit_files_domain(TALLOC_CTX *tmp_ctx,
                                        struct confdb_ctx *cdb,
                                        struct ldb_result *doms)
@@ -2226,23 +2237,17 @@ done:
 static int confdb_ensure_files_domain(struct confdb_ctx *cdb,
                                       const char *implicit_files_dom_name)
 {
-#ifdef ADD_FILES_DOMAIN
-    const bool default_enable_files = true;
-#else
-    const bool default_enable_files = false;
-#endif
     errno_t ret;
     bool enable_files;
 
     ret = confdb_get_bool(cdb,
                           CONFDB_MONITOR_CONF_ENTRY,
                           CONFDB_MONITOR_ENABLE_FILES_DOM,
-                          default_enable_files, &enable_files);
+                          false, &enable_files);
     if (ret != EOK) {
         DEBUG(SSSDBG_MINOR_FAILURE,
-              "Cannot get the value of %s assuming %s\n",
-              CONFDB_MONITOR_ENABLE_FILES_DOM,
-              default_enable_files ? "true" : "false");
+              "Cannot get the value of %s\n",
+              CONFDB_MONITOR_ENABLE_FILES_DOM);
         return ret;
     }
 
@@ -2269,6 +2274,7 @@ static int confdb_ensure_files_domain(struct confdb_ctx *cdb,
 
     return activate_files_domain(cdb, implicit_files_dom_name);
 }
+#endif
 
 static int confdb_get_parent_domain(TALLOC_CTX *mem_ctx,
                                     const char *name,
@@ -2457,6 +2463,7 @@ int confdb_expand_app_domains(struct confdb_ctx *cdb)
         return ENOMEM;
     }
 
+#ifdef BUILD_FILES_PROVIDER
     ret = confdb_ensure_files_domain(cdb, IMPLICIT_FILES_DOMAIN_NAME);
     if (ret != EOK) {
         DEBUG(SSSDBG_MINOR_FAILURE,
@@ -2464,6 +2471,7 @@ int confdb_expand_app_domains(struct confdb_ctx *cdb)
               ret, strerror(ret));
         /* Not fatal */
     }
+#endif
 
     ret = confdb_get_enabled_domain_list(cdb, tmp_ctx, &domlist);
     if (ret == ENOENT) {
@@ -2566,6 +2574,7 @@ static errno_t certmap_local_check(struct ldb_message *msg)
 static errno_t confdb_get_all_certmaps(TALLOC_CTX *mem_ctx,
                                        struct confdb_ctx *cdb,
                                        struct sss_domain_info *dom,
+                                       bool certmaps_for_local_users,
                                        struct certmap_info ***_certmap_list)
 {
     TALLOC_CTX *tmp_ctx = NULL;
@@ -2611,7 +2620,7 @@ static errno_t confdb_get_all_certmaps(TALLOC_CTX *mem_ctx,
     }
 
     for (c = 0; c < res->count; c++) {
-        if (is_files_provider(dom)) {
+        if (certmaps_for_local_users) {
             ret = certmap_local_check(res->msgs[c]);
             if (ret != EOK) {
                 DEBUG(SSSDBG_CONF_SETTINGS,
@@ -2639,7 +2648,8 @@ done:
 }
 
 int confdb_certmap_to_sysdb(struct confdb_ctx *cdb,
-                            struct sss_domain_info *dom)
+                            struct sss_domain_info *dom,
+                            bool certmaps_for_local_users)
 {
     int ret;
     TALLOC_CTX *tmp_ctx;
@@ -2651,7 +2661,8 @@ int confdb_certmap_to_sysdb(struct confdb_ctx *cdb,
         return ENOMEM;
     }
 
-    ret = confdb_get_all_certmaps(tmp_ctx, cdb, dom, &certmap_list);
+    ret = confdb_get_all_certmaps(tmp_ctx, cdb, dom, certmaps_for_local_users,
+                                  &certmap_list);
     if (ret != EOK) {
         DEBUG(SSSDBG_OP_FAILURE, "confdb_get_all_certmaps failed.\n");
         goto done;
