@@ -27,6 +27,7 @@
 #include <sys/stat.h>
 #include <signal.h>
 #include <popt.h>
+#include <sys/prctl.h>
 
 #include "util/util.h"
 #include "util/sss_krb5.h"
@@ -211,6 +212,7 @@ static int lc_verify_keytab_ex(const char *principal,
             DEBUG(SSSDBG_FATAL_FAILURE,
                   "Could not parse keytab entry\n");
             sss_log(SSS_LOG_ERR, "Could not parse keytab entry\n");
+            krb5_kt_end_seq_get(context, keytab, &cursor);
             return EIO;
         }
 
@@ -365,12 +367,6 @@ static krb5_error_code ldap_child_get_tgt_sync(TALLOC_CTX *memctx,
     }
     DEBUG(SSSDBG_CONF_SETTINGS, "Principal name is: [%s]\n", full_princ);
 
-    krberr = krb5_parse_name(context, full_princ, &kprinc);
-    if (krberr != 0) {
-        DEBUG(SSSDBG_OP_FAILURE, "krb5_parse_name() failed: %d\n", krberr);
-        goto done;
-    }
-
     if (keytab_name) {
         krberr = krb5_kt_resolve(context, keytab_name, &keytab);
     } else {
@@ -445,8 +441,14 @@ static krb5_error_code ldap_child_get_tgt_sync(TALLOC_CTX *memctx,
         goto done;
     }
 
+    krberr = krb5_parse_name(context, full_princ, &kprinc);
+    if (krberr != 0) {
+        DEBUG(SSSDBG_OP_FAILURE, "krb5_parse_name() failed: %d\n", krberr);
+        goto done;
+    }
     krberr = krb5_get_init_creds_keytab(context, &my_creds, kprinc,
                                         keytab, 0, NULL, options);
+    krb5_free_principal(context, kprinc);
     if (krberr != 0) {
         DEBUG(SSSDBG_OP_FAILURE,
               "krb5_get_init_creds_keytab() failed: %d\n", krberr);
@@ -619,6 +621,7 @@ int main(int argc, const char *argv[])
     int ret;
     int kerr;
     int opt;
+    int dumpable = 1;
     int debug_fd = -1;
     const char *opt_logger = NULL;
     poptContext pc;
@@ -635,6 +638,8 @@ int main(int argc, const char *argv[])
     struct poptOption long_options[] = {
         POPT_AUTOHELP
         SSSD_DEBUG_OPTS
+        {"dumpable", 0, POPT_ARG_INT, &dumpable, 0,
+         _("Allow core dumps"), NULL },
         {"debug-fd", 0, POPT_ARG_INT, &debug_fd, 0,
          _("An open file descriptor for the debug logs"), NULL},
         SSSD_LOGGER_OPTS
@@ -657,6 +662,8 @@ int main(int argc, const char *argv[])
 
     poptFreeContext(pc);
 
+    prctl(PR_SET_DUMPABLE, (dumpable == 0) ? 0 : 1);
+
     debug_prg_name = talloc_asprintf(NULL, "ldap_child[%d]", getpid());
     if (!debug_prg_name) {
         debug_prg_name = "ldap_child";
