@@ -1072,6 +1072,9 @@ struct gethostbyname_state {
     int retrying;
 };
 
+static errno_t
+resolv_gethostbyname_unix(TALLOC_CTX *mem_ctx, const char *path,
+                          struct resolv_hostent **_rhostent);
 static errno_t
 resolv_gethostbyname_address(TALLOC_CTX *mem_ctx, const char *address,
                              struct resolv_hostent **_rhostent);
@@ -1118,6 +1121,21 @@ resolv_gethostbyname_send(TALLOC_CTX *mem_ctx, struct tevent_context *ev,
     state->db = db;
     state->dbi = 0;
 
+    /* Do not attempt to resolve unix domain sockets */
+    if (resolv_is_unix(state->name)) {
+        ret = resolv_gethostbyname_unix(state, state->name,
+                                        &state->rhostent);
+        if (ret != EOK) {
+            DEBUG(SSSDBG_CRIT_FAILURE,
+                  "Cannot create a fake hostent structure\n");
+            goto fail;
+        }
+
+        tevent_req_done(req);
+        tevent_req_post(req, ev);
+        return req;
+    }
+
     /* Do not attempt to resolve IP addresses */
     if (resolv_is_address(state->name)) {
         ret = resolv_gethostbyname_address(state, state->name,
@@ -1146,6 +1164,18 @@ fail:
     return NULL;
 }
 
+bool
+resolv_is_unix(const char *name)
+{
+    if (name && name[0] == '/') {
+        return 1;
+    }
+    DEBUG(SSSDBG_TRACE_ALL,
+          "[%s] does not look like a unix domain socket\n", name);
+
+    return 0;
+}
+
 bool
 resolv_is_address(const char *name)
 {
@@ -1173,6 +1203,43 @@ resolv_is_address(const char *name)
     return ret == 0;
 }
 
+static errno_t
+resolv_gethostbyname_unix(TALLOC_CTX *mem_ctx, const char *path,
+                          struct resolv_hostent **_rhostent)
+{
+    struct resolv_hostent *rhostent;
+    TALLOC_CTX *tmp_ctx;
+    errno_t ret;
+
+    tmp_ctx = talloc_new(NULL);
+    if (!tmp_ctx) return ENOMEM;
+
+    rhostent = talloc_zero(tmp_ctx, struct resolv_hostent);
+    if (!rhostent) {
+        ret = ENOMEM;
+        goto done;
+    }
+
+    rhostent->name = talloc_strdup(rhostent, path);
+    rhostent->addr_list = talloc_array(rhostent, struct resolv_addr *, 1);
+
+    if (!rhostent->name ||
+        !rhostent->addr_list) {
+        ret = ENOMEM;
+        goto done;
+    }
+
+    rhostent->addr_list[0] = NULL;
+    rhostent->family = AF_UNIX;
+    rhostent->aliases = NULL;
+
+    *_rhostent = talloc_move(mem_ctx, &rhostent);
+    ret = EOK;
+done:
+    talloc_free(tmp_ctx);
+    return ret;
+}
+
 static errno_t
 resolv_gethostbyname_address(TALLOC_CTX *mem_ctx, const char *address,
                              struct resolv_hostent **_rhostent)
@@ -1468,16 +1535,34 @@ resolv_get_string_ptr_address(TALLOC_CTX *mem_ctx,
     return straddr;
 }
 
-struct sockaddr_storage *
+struct sockaddr *
 resolv_get_sockaddr_address_index(TALLOC_CTX *mem_ctx,
                                   struct resolv_hostent *hostent,
-                                  int port, int addrindex)
+                                  int port, int addrindex,
+                                  socklen_t *sockaddr_len)
 {
-    struct sockaddr_storage *sockaddr;
+    struct sockaddr *sockaddr;
+    int len;
 
     if (!hostent) return NULL;
 
-    sockaddr = talloc_zero(mem_ctx, struct sockaddr_storage);
+    switch(hostent->family) {
+        case AF_INET:
+            len = sizeof(struct sockaddr_in);
+            break;
+        case AF_INET6:
+            len = sizeof(struct sockaddr_in6);
+            break;
+        case AF_UNIX:
+            len = sizeof(struct sockaddr_un);
+            break;
+        default:
+            DEBUG(SSSDBG_CRIT_FAILURE,
+                  "Unknown address family %d\n", hostent->family);
+            return NULL;
+    }
+
+    sockaddr = (struct sockaddr *)talloc_zero(mem_ctx, struct sockaddr_storage);
     if (sockaddr == NULL) {
         DEBUG(SSSDBG_CRIT_FAILURE, "talloc_zero failed.\n");
         return NULL;
@@ -1485,7 +1570,7 @@ resolv_get_sockaddr_address_index(TALLOC_CTX *mem_ctx,
 
     switch(hostent->family) {
         case AF_INET:
-            sockaddr->ss_family = AF_INET;
+            sockaddr->sa_family = AF_INET;
             memcpy(&((struct sockaddr_in *) sockaddr)->sin_addr,
                    hostent->addr_list[addrindex]->ipaddr,
                    sizeof(struct in_addr));
@@ -1493,18 +1578,33 @@ resolv_get_sockaddr_address_index(TALLOC_CTX *mem_ctx,
 
             break;
         case AF_INET6:
-            sockaddr->ss_family = AF_INET6;
+            sockaddr->sa_family = AF_INET6;
             memcpy(&((struct sockaddr_in6 *) sockaddr)->sin6_addr,
                    hostent->addr_list[addrindex]->ipaddr,
                    sizeof(struct in6_addr));
             ((struct sockaddr_in6 *) sockaddr)->sin6_port = (in_port_t) htons(port);
             break;
-        default:
+        case AF_UNIX:
+            sockaddr->sa_family = AF_UNIX;
+            strncpy(((struct sockaddr_un *) sockaddr)->sun_path, hostent->name,
+                    sizeof(((struct sockaddr_un *) sockaddr)->sun_path) - 1);
+            if (strlen(hostent->name) >=
+                    sizeof(((struct sockaddr_un *) sockaddr)->sun_path)) {
+                DEBUG(SSSDBG_CRIT_FAILURE,
+                      "Path '%s' too long\n", hostent->name);
+                return NULL;
+            }
+	    break;
+	default:
             DEBUG(SSSDBG_CRIT_FAILURE,
                   "Unknown address family %d\n", hostent->family);
             return NULL;
     }
 
+    if (sockaddr_len != NULL) {
+        *sockaddr_len = len;
+    }
+
     return sockaddr;
 }
 
