@@ -49,12 +49,6 @@ extern hash_table_t *dp_requests;
  * So we set umask to 0111. */
 #define SCKT_RSP_UMASK 0111
 
-/* Files provider doesn't have a back end in the traditional sense
- * and can always just consult the responder's cache
- */
-#define NEED_CHECK_PROVIDER(provider) \
-    ((provider != NULL) && (strcmp(provider, "files") != 0))
-
 /* needed until nsssrv.h is updated */
 struct cli_request {
 
@@ -336,9 +330,10 @@ errno_t sss_dp_get_domains_recv(struct tevent_req *req);
  * @param   domain      The SSSD domain we're querying. The response can
  *                      be either NULL or come from any of domain's subdomains
  *                      or domain itself
- * @param   type        Either SSS_DP_USER or SSS_DP_GROUP, other types
- *                      are not supported at the moment
+ * @param   type        Either SSS_DP_USER, SSS_DP_GROUP or SSS_DP_SECID, other
+ *                      types  are not supported at the moment
  * @param   opt_id      The ID number we're trying to locate
+ * @param   opt_str     The SID number we're trying to locate
  *
  * @return  A tevent request or NULL if allocating the request fails.
  */
@@ -347,7 +342,8 @@ struct tevent_req *sss_dp_get_account_domain_send(TALLOC_CTX *mem_ctx,
                                                   struct sss_domain_info *domain,
                                                   bool fast_reply,
                                                   enum sss_dp_acct_type type,
-                                                  uint32_t opt_id);
+                                                  uint32_t opt_id,
+                                                  const char *opt_str);
 
 /* Receive a getAccountDomain request result
  *
@@ -372,12 +368,11 @@ errno_t schedule_get_domains_task(TALLOC_CTX *mem_ctx,
                                   void *callback_pvt);
 
 errno_t csv_string_to_uid_array(TALLOC_CTX *mem_ctx, const char *csv_string,
-                                bool allow_sss_loop,
                                 size_t *_uid_count, uid_t **_uids);
 
 uid_t client_euid(struct cli_creds *creds);
 errno_t check_allowed_uids(uid_t uid, size_t allowed_uids_count,
-                           uid_t *allowed_uids);
+                           const uid_t *allowed_uids);
 
 struct tevent_req *
 sss_parse_inp_send(TALLOC_CTX *mem_ctx,
