@@ -24,10 +24,13 @@
 #include "util/crypto/sss_crypto.h"
 #include "util/util.h"
 #include "util/sss_krb5.h"
+#include "src/providers/krb5/krb5_ccache.h"
+#include "responder/kcm/kcm_renew.h"
 #include "responder/kcm/kcmsrv_ccache.h"
 #include "responder/kcm/kcmsrv_ccache_pvt.h"
 #include "responder/kcm/kcmsrv_ccache_be.h"
 
+
 static struct kcm_cred *kcm_cred_dup(TALLOC_CTX *mem_ctx,
                                      struct kcm_cred *crd);
 
@@ -37,7 +40,9 @@ static int kcm_cc_destructor(struct kcm_ccache *cc)
         return 0;
     }
 
-    krb5_free_principal(NULL, cc->client);
+    if (cc->client != NULL) {
+        krb5_free_principal(NULL, cc->client);
+    }
     return 0;
 }
 
@@ -228,7 +233,6 @@ struct kcm_cred *kcm_cred_new(TALLOC_CTX *mem_ctx,
     if (kcreds == NULL) {
         return NULL;
     }
-
     uuid_copy(kcreds->uuid, uuid);
     kcreds->cred_blob = talloc_steal(kcreds, cred_blob);
     return kcreds;
@@ -250,10 +254,93 @@ static struct kcm_cred *kcm_cred_dup(TALLOC_CTX *mem_ctx,
     return dup;
 }
 
+#ifdef HAVE_KRB5_UNMARSHAL_CREDENTIALS
+static krb5_creds *kcm_cred_to_krb5(krb5_context kctx, struct kcm_cred *kcm_crd)
+{
+    krb5_error_code kerr;
+    krb5_creds *kcrd;
+    krb5_data data;
+
+    get_krb5_data_from_cred(kcm_crd->cred_blob, &data);
+
+    kerr = krb5_unmarshal_credentials(kctx, &data, &kcrd);
+    if (kerr != 0) {
+        DEBUG(SSSDBG_CRIT_FAILURE, "Failed to unmarshal credentials\n");
+        return NULL;
+    }
+
+    return kcrd;
+}
+#endif
+
+static errno_t
+kcm_cc_remove_duplicates(struct kcm_ccache *cc,
+                         struct kcm_cred *kcm_crd)
+{
+#ifdef HAVE_KRB5_UNMARSHAL_CREDENTIALS
+    struct kcm_cred *p, *q;
+    krb5_error_code kerr;
+    krb5_context kctx;
+    krb5_creds *kcrd_cc;
+    krb5_creds *kcrd;
+    errno_t ret;
+    bool bret;
+
+    kerr = krb5_init_context(&kctx);
+    if (kerr != 0) {
+        DEBUG(SSSDBG_CRIT_FAILURE, "Failed to init krb5 context\n");
+        return EIO;
+    }
+
+    kcrd = kcm_cred_to_krb5(kctx, kcm_crd);
+    if (kcrd == NULL) {
+        DEBUG(SSSDBG_CRIT_FAILURE, "Failed to convert kcm cred to krb5\n");
+        ret = ERR_INTERNAL;
+        goto done;
+    }
+
+    DLIST_FOR_EACH_SAFE(p, q, cc->creds) {
+        kcrd_cc = kcm_cred_to_krb5(kctx, p);
+        if (kcrd_cc == NULL) {
+            DEBUG(SSSDBG_CRIT_FAILURE, "Failed to convert kcm cred to krb5\n");
+            ret = ERR_INTERNAL;
+            goto done;
+        }
+
+        bret = sss_krb5_creds_compare(kctx, kcrd, kcrd_cc);
+        krb5_free_creds(kctx, kcrd_cc);
+        if (!bret) {
+            continue;
+        }
+
+        /* This cred is the same ticket. We will replace it with the new one. */
+        DLIST_REMOVE(cc->creds, p);
+    }
+
+    ret = EOK;
+
+done:
+    krb5_free_creds(kctx, kcrd);
+    krb5_free_context(kctx);
+
+    return ret;
+#else
+    return EOK;
+#endif
+}
+
 /* Add a cred to ccache */
 errno_t kcm_cc_store_creds(struct kcm_ccache *cc,
                            struct kcm_cred *crd)
 {
+    errno_t ret;
+
+    ret = kcm_cc_remove_duplicates(cc, crd);
+    if (ret != EOK) {
+        DEBUG(SSSDBG_MINOR_FAILURE, "Unable to remove duplicate credentials "
+              "[%d]: %s\n", ret, sss_strerror(ret));
+    }
+
     DLIST_ADD(cc->creds, crd);
     talloc_steal(cc, crd);
     return EOK;
@@ -279,6 +366,73 @@ errno_t kcm_cc_set_header(struct kcm_ccache *cc,
     return EOK;
 }
 
+#ifdef HAVE_KCM_RENEWAL
+static int kcm_cc_unmarshal_destructor(krb5_creds **creds)
+{
+    krb5_error_code kerr;
+    krb5_context krb_ctx;
+    int i;
+
+    kerr = krb5_init_context(&krb_ctx);
+    if (kerr != 0) {
+        DEBUG(SSSDBG_CRIT_FAILURE, "Failed to init krb5 context\n");
+        return 1;
+    }
+
+    for (i = 0; creds[i] != NULL; i++) {
+        krb5_free_creds(krb_ctx, creds[i]);
+    }
+
+    krb5_free_context(krb_ctx);
+
+    return 0;
+}
+#endif
+
+krb5_creds **kcm_cc_unmarshal(TALLOC_CTX *mem_ctx,
+                              krb5_context krb_context,
+                              struct kcm_ccache *cc)
+{
+#ifndef HAVE_KCM_RENEWAL
+    return NULL;
+#else
+    TALLOC_CTX *tmp_ctx;
+    struct kcm_cred *cred;
+    krb5_creds **cred_list;
+    int i = 0;
+    int count = 0;
+
+    tmp_ctx = talloc_new(NULL);
+    if (tmp_ctx == NULL) {
+        goto done;
+    }
+
+    for (cred = kcm_cc_get_cred(cc); cred != NULL; cred = kcm_cc_next_cred(cred)) {
+        count++;
+    }
+
+    cred_list = talloc_array(tmp_ctx, krb5_creds *, count + 1);
+
+    for (cred = kcm_cc_get_cred(cc); cred != NULL; cred = kcm_cc_next_cred(cred), i++) {
+        cred_list[i] = kcm_cred_to_krb5(krb_context, cred);
+        if (cred_list[i] == NULL) {
+            DEBUG(SSSDBG_CRIT_FAILURE, "Failed to convert kcm cred to krb5\n");
+            goto done;
+        }
+    }
+
+    cred_list[count] = NULL;
+    talloc_set_destructor(cred_list, kcm_cc_unmarshal_destructor);
+
+    talloc_steal(mem_ctx, cred_list);
+
+    return cred_list;
+done:
+    talloc_free(tmp_ctx);
+    return NULL;
+#endif
+}
+
 errno_t kcm_cred_get_uuid(struct kcm_cred *crd, uuid_t _uuid)
 {
     if (crd == NULL) {
@@ -293,6 +447,43 @@ struct sss_iobuf *kcm_cred_get_creds(struct kcm_cred *crd)
     return crd ? crd->cred_blob : NULL;
 }
 
+errno_t kcm_ccdb_renew_tgts(TALLOC_CTX *mem_ctx,
+                            struct krb5_ctx *krb5_ctx,
+                            struct tevent_context *ev,
+                            struct kcm_ccdb *ccdb,
+                            struct kcm_ccache ***_cc_list)
+{
+    struct kcm_ccache **cc;
+    errno_t ret;
+
+    if (krb5_ctx == NULL || ev == NULL || ccdb == NULL) {
+        ret = EINVAL;
+        return ret;
+    }
+
+    if (ccdb->ops->list_all_cc == NULL) {
+        ret = EINVAL;
+        DEBUG(SSSDBG_TRACE_INTERNAL, "List all cc function not available\n");
+        goto done;
+    }
+
+    ret = ccdb->ops->list_all_cc(mem_ctx, krb5_ctx, ev, ccdb, &cc);
+    if (ret != EOK && ret != ENOENT) {
+        DEBUG(SSSDBG_CRIT_FAILURE, "Failure to retrieve list of ccaches"
+                                   "[%d]: %s\n", ret, sss_strerror(ret));
+        return ret;
+    } else if (ret == ENOENT) {
+        goto done;
+    }
+
+    *_cc_list = talloc_steal(mem_ctx, cc);
+
+    ret = EOK;
+done:
+
+    return ret;
+}
+
 struct kcm_ccdb *kcm_ccdb_init(TALLOC_CTX *mem_ctx,
                                struct tevent_context *ev,
                                struct confdb_ctx *cdb,
@@ -317,18 +508,12 @@ struct kcm_ccdb *kcm_ccdb_init(TALLOC_CTX *mem_ctx,
         DEBUG(SSSDBG_FUNC_DATA, "KCM back end: memory\n");
         ccdb->ops = &ccdb_mem_ops;
         break;
-#ifdef BUILD_SECRETS
-    case CCDB_BE_SECRETS:
-        DEBUG(SSSDBG_FUNC_DATA, "KCM back end: sssd-secrets\n");
-        ccdb->ops = &ccdb_sec_ops;
-        break;
-#endif /* BUILD_SECRETS */
     case CCDB_BE_SECDB:
         DEBUG(SSSDBG_FUNC_DATA, "KCM back end: libsss_secrets\n");
         ccdb->ops = &ccdb_secdb_ops;
         break;
     default:
-        DEBUG(SSSDBG_CRIT_FAILURE, "Unknown ccache database\n");
+        DEBUG(SSSDBG_CRIT_FAILURE, "Unknown ccache database backend\n");
         break;
     }
 
