@@ -61,7 +61,7 @@ int ssh_process_init(TALLOC_CTX *mem_ctx,
     ssh_ctx->rctx->pvt_ctx = ssh_ctx;
 
     ret = sss_names_init_from_args(ssh_ctx,
-                                   "(?P<name>[^@]+)@?(?P<domain>[^@]*$)",
+                                   SSS_DEFAULT_RE,
                                    "%1$s@%2$s", &ssh_ctx->snctx);
     if (ret != EOK) {
         DEBUG(SSSDBG_FATAL_FAILURE, "fatal error initializing regex data\n");
