@@ -167,7 +167,7 @@ sss_dp_get_sudoers_send(TALLOC_CTX *mem_ctx,
         return NULL;
     }
 
-    if (NEED_CHECK_PROVIDER(dom->provider) == false) {
+    if (is_files_provider(dom)) {
         DEBUG(SSSDBG_TRACE_INTERNAL, "Domain %s does not check DP\n",
               dom->name);
         state->dp_error = DP_ERR_OK;
@@ -209,10 +209,13 @@ sss_dp_get_sudoers_send(TALLOC_CTX *mem_ctx,
     ret = EAGAIN;
 
 done:
+#ifdef BUILD_FILES_PROVIDER
     if (ret == EOK) {
         tevent_req_done(req);
         tevent_req_post(req, rctx->ev);
-    } else if (ret != EAGAIN) {
+    } else
+#endif
+    if (ret != EAGAIN) {
         tevent_req_error(req, ret);
         tevent_req_post(req, rctx->ev);
     }
