@@ -109,7 +109,7 @@ static void test_sss_authtok_password(void **state)
     assert_int_equal(ret, EOK);
     assert_int_equal(type, sss_authtok_get_type(ts->authtoken));
     assert_int_equal(len, sss_authtok_get_size(ts->authtoken));
-    assert_string_equal(data, sss_authtok_get_data(ts->authtoken));
+    assert_string_equal(data, (char *)sss_authtok_get_data(ts->authtoken));
 
     ret = sss_authtok_get_password(ts->authtoken, &pwd, &ret_len);
 
@@ -151,7 +151,7 @@ static void test_sss_authtok_ccfile(void **state)
     assert_int_equal(ret, EOK);
     assert_int_equal(type, sss_authtok_get_type(ts->authtoken));
     assert_int_equal(len, sss_authtok_get_size(ts->authtoken));
-    assert_string_equal(data, sss_authtok_get_data(ts->authtoken));
+    assert_string_equal(data, (char *)sss_authtok_get_data(ts->authtoken));
 
     ret = sss_authtok_get_ccfile(ts->authtoken, &pwd, &ret_len);
 
@@ -175,7 +175,7 @@ static void test_sss_authtok_ccfile(void **state)
     assert_int_equal(ret, EOK);
     assert_int_equal(type, sss_authtok_get_type(ts->authtoken));
     assert_int_equal(len, sss_authtok_get_size(ts->authtoken));
-    assert_string_equal(data, sss_authtok_get_data(ts->authtoken));
+    assert_string_equal(data, (char *)sss_authtok_get_data(ts->authtoken));
 
     ret = sss_authtok_get_ccfile(ts->authtoken, &pwd, &ret_len);
 
@@ -302,7 +302,7 @@ static void test_sss_authtok_copy(void **state)
 
     assert_int_equal(ret, EOK);
     assert_int_equal(type, sss_authtok_get_type(dest_authtoken));
-    assert_string_equal(data, sss_authtok_get_data(dest_authtoken));
+    assert_string_equal(data, (char *)sss_authtok_get_data(dest_authtoken));
     assert_int_equal(len, sss_authtok_get_size(dest_authtoken));
 
     sss_authtok_set_empty(dest_authtoken);
@@ -689,7 +689,7 @@ static void test_sss_authtok_2fa_single(void **state)
     assert_int_equal(ret, EOK);
     assert_int_equal(type, sss_authtok_get_type(ts->authtoken));
     assert_int_equal(len, sss_authtok_get_size(ts->authtoken));
-    assert_string_equal(data, sss_authtok_get_data(ts->authtoken));
+    assert_string_equal(data, (char *)sss_authtok_get_data(ts->authtoken));
 
     ret = sss_authtok_get_2fa_single(ts->authtoken, &pwd, &ret_len);
 
@@ -709,6 +709,48 @@ static void test_sss_authtok_2fa_single(void **state)
     sss_authtok_set_empty(ts->authtoken);
 }
 
+/* Test when type has value SSS_AUTHTOK_TYPE_OAUTH2 */
+static void test_sss_authtok_oauth2(void **state)
+{
+    size_t len;
+    errno_t ret;
+    char *data;
+    size_t ret_len;
+    const char *pwd;
+    struct test_state *ts;
+    enum sss_authtok_type type;
+
+    ts = talloc_get_type_abort(*state, struct test_state);
+    data = talloc_strdup(ts, "one-time-password");
+    assert_non_null(data);
+
+    len = strlen(data) + 1;
+    type = SSS_AUTHTOK_TYPE_OAUTH2;
+    ret = sss_authtok_set(ts->authtoken, type, (const uint8_t *)data, len);
+
+    assert_int_equal(ret, EOK);
+    assert_int_equal(type, sss_authtok_get_type(ts->authtoken));
+    assert_int_equal(len, sss_authtok_get_size(ts->authtoken));
+    assert_string_equal(data, (char *)sss_authtok_get_data(ts->authtoken));
+
+    ret = sss_authtok_get_oauth2(ts->authtoken, &pwd, &ret_len);
+
+    assert_int_equal(ret, EOK);
+    assert_string_equal(data, pwd);
+    assert_int_equal(len - 1, ret_len);
+
+    ret = sss_authtok_set_oauth2(ts->authtoken, data, len);
+    assert_int_equal(ret, EOK);
+
+    ret = sss_authtok_get_oauth2(ts->authtoken, &pwd, &ret_len);
+    assert_int_equal(ret, EOK);
+    assert_string_equal(data, pwd);
+    assert_int_equal(len - 1, ret_len);
+
+    talloc_free(data);
+    sss_authtok_set_empty(ts->authtoken);
+}
+
 
 int main(int argc, const char *argv[])
 {
@@ -747,6 +789,8 @@ int main(int argc, const char *argv[])
                                         setup, teardown),
         cmocka_unit_test_setup_teardown(test_sss_authtok_2fa_single,
                                         setup, teardown),
+        cmocka_unit_test_setup_teardown(test_sss_authtok_oauth2,
+                                        setup, teardown),
     };
 
     /* Set debug level to invalid value so we can decide if -d 0 was used. */
